Package 'SpaGER'

Title: Spatial Gene Expression Prediction using scRNA-seq
Description: Integrates spatial transcriptomics data with single-cell RNA sequencing (scRNA-seq) data to predict expression of unmeasured genes in spatial data. Uses Principal Vectors (PVs) for domain adaptation followed by k-nearest neighbor weighted imputation. This R implementation provides identical results to the original Python SpaGE package with efficient C++ acceleration.
Authors: Zaoqu Liu [aut, cre] , Tamim Abdelaal [ctb] (Original SpaGE algorithm), Soufiane Mourragui [ctb] (PRECISE algorithm)
Maintainer: Zaoqu Liu <[email protected]>
License: MIT + file LICENSE
Version: 1.0.0
Built: 2026-05-24 07:47:23 UTC
Source: https://github.com/Zaoqu-Liu/SpaGER

Help Index